@@ -58,15 +58,15 @@ class Data(ByteArray):
         else:
             self._size = size
 
-    @property
+    @property  # Override
     def buffer(self) -> Union[bytes, bytearray]:
         return self._buffer
 
-    @property
+    @property  # Override
     def offset(self) -> int:
         return self._offset
 
-    @property
+    @property  # Override
     def size(self) -> int:
         return self._size
 
@@ -114,11 +114,16 @@ class Data(ByteArray):
         # return data.decode('utf-8')
         return str(data)
 
-    @property
+    def __add__(self, other):
+        """ self + other """
+        return concat(left=self, right=other)
+
+    @property  # Override
     def hex_string(self) -> str:
         data = self.get_bytes()
         return hex_encode(data=data)
 
+    # Override
     def get_byte(self, index: int) -> int:
         index = get_data_helper().adjust_e(index=index, size=self._size)
         if index >= self._size:
@@ -126,6 +131,7 @@ class Data(ByteArray):
             raise IndexError('error index: %d, size: %d' % (index, self._size))
         return self._buffer[self._offset + index]
 
+    # Override
     def get_bytes(self, start: int = 0, end: int = None) -> bytes:
         start, end = adjust_positions(size=self._size, start=start, end=end)
         sub = get_slice(data=self, start=start, end=end)
@@ -134,6 +140,7 @@ class Data(ByteArray):
         else:
             return sub
 
+    # Override
     def slice(self, start: int, end: int = None) -> ByteArray:
         start, end = adjust_positions(size=self._size, start=start, end=end)
         if start == 0 and end == self._size:
@@ -146,18 +153,11 @@ class Data(ByteArray):
             # error
             return self.ZERO
 
+    # Override
     def concat(self, other: Union[bytes, bytearray, ByteArray]) -> ByteArray:
-        if other is None:
-            # other data is empty, take this data
-            return self
-        if not isinstance(other, ByteArray):
-            other = Data(buffer=other)
-        if self._size > 0:
-            return get_data_helper().concat(left=self, right=other)
-        else:
-            # this data is empty, take the other one
-            return other
+        return concat(left=self, right=other)
 
+    # Override
     def find(self, sub: Union[bytes, bytearray, ByteArray], start: int = 0, end: int = None) -> int:
         if not isinstance(sub, ByteArray):
             sub = Data(buffer=sub)
@@ -174,6 +174,26 @@ class Data(ByteArray):
         return cls(buffer=random_bytes(size=size))
 
 
+def convert(data: Union[bytes, bytearray, ByteArray]) -> ByteArray:
+    if data is None:
+        return Data.ZERO
+    elif isinstance(data, ByteArray):
+        return data
+    else:
+        return Data(buffer=data)
+
+
+def concat(left: Union[bytes, bytearray, ByteArray], right: Union[bytes, bytearray, ByteArray]) -> ByteArray:
+    left = convert(data=left)
+    right = convert(data=right)
+    if left.size == 0:
+        return right
+    elif right.size == 0:
+        return left
+    else:
+        return get_data_helper().concat(left=left, right=right)
+
+
 # get slice with range [start, end)
 def get_slice(data: ByteArray, start: int, end: int) -> Union[bytes, bytearray]:
     if start >= end:
